@@ -1,11 +1,11 @@
 import numpy as np
-from spotpython.fun.objectivefunctions import analytical
+from spotpython.fun.objectivefunctions import Analytical
 from spotpython.spot import spot
 from spotpython.utils.init import fun_control_init
 
 
 def test_chg():
-    fun = analytical().fun_sphere
+    fun = Analytical().fun_sphere
     lower = np.array([-1, -1])
     upper = np.array([1, 1])
     S = spot.Spot(fun=fun, fun_control=fun_control_init(lower=lower, upper=upper))
