@@ -4,11 +4,12 @@ from spotpython.fun.objectivefunctions import Analytical
 
 def test_fun_wingwt():
     """Test the fun_wingwt method from the Analytical class."""
-    # Create a small test input with shape (n, 10)
+    # Create a small test input with shape (2, 10)
+    # Here we use the lower and upper bounds of the wing weight function
     X_test = np.array([
-        [0.0]*10,
-        [1.0]*10
-    ])
+    [150, 220,   6, -10, 16, 0.5, 0.08, 2.5, 1700, 0.025],
+    [200, 300,  10,  10, 45, 1.0, 0.18, 6.0, 2500, 0.08 ],
+])
     fun = Analytical()
     result = fun.fun_wingwt(X_test)
 
